@@ -54,13 +54,17 @@
   // the feed is dynamic - we need a cache for each combo
   // (but most people just use the default feed so it's still effective)
   $cache = getCacheName($num.$type.$mode.$ns.$ltype.$_SERVER['REMOTE_USER'],'.feed');
+  $cmod = @filemtime($cache); // 0 if not exists
+  if ($cmod && (@filemtime(DOKU_CONF.'local.php')>$cmod || @filemtime(DOKU_CONF.'dokuwiki.php')>$cmod)) {
+    // ignore cache if feed prefs may have changed
+    $cmod = 0;
+  }
 
   // check cacheage and deliver if nothing has changed since last
   // time or the update interval has not passed, also handles conditional requests
   header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
   header('Pragma: public');
   header('Content-Type: application/xml; charset=utf-8');
-  $cmod = @filemtime($cache); // 0 if not exists
   if($cmod && (($cmod+$conf['rss_update']>time()) || ($cmod>@filemtime($conf['changelog'])))){
     http_conditionalRequest($cmod);
     if($conf['allowdebug']) header("X-CacheUsed: $cache");
@@ -75,7 +79,7 @@
   $rss->title = $conf['title'].(($ns) ? ' '.$ns : '');
   $rss->link  = DOKU_URL;
   $rss->syndicationURL = DOKU_URL.'feed.php';
-  $rss->cssStyleSheet  = DOKU_URL.'lib/styles/feed.css';
+  $rss->cssStyleSheet  = DOKU_URL.'lib/exe/css.php?s=feed';
 
   $image = new FeedImage();
   $image->title = $conf['title'];
@@ -126,7 +130,7 @@ function rssRecentChanges(&$rss,$num,$ltype,$ns,$minor){
         }else{
             $item->title = $recent['id'];
         }
-        if(!empty($recent['sum'])){
+        if($conf['rss_show_summary'] && !empty($recent['sum'])){
             $item->title .= ' - '.strip_tags($recent['sum']);
         }
 
@@ -134,17 +138,17 @@ function rssRecentChanges(&$rss,$num,$ltype,$ns,$minor){
 
         switch ($ltype){
             case 'page':
-                $item->link = wl($recent['id'],'rev='.$recent['date'],true);
+                $item->link = wl($recent['id'],'rev='.$recent['date'],true,'&');
                 break;
             case 'rev':
-                $item->link = wl($recent['id'],'do=revisions&rev='.$recent['date'],true);
+                $item->link = wl($recent['id'],'do=revisions&rev='.$recent['date'],true,'&');
                 break;
             case 'current':
-                $item->link = wl($recent['id'], '', true);
+                $item->link = wl($recent['id'], '', true,'&');
                 break;
             case 'diff':
             default:
-                $item->link = wl($recent['id'],'rev='.$recent['date'].'&do=diff'.$recent['date'],true);
+                $item->link = wl($recent['id'],'rev='.$recent['date'].'&do=diff',true,'&');
         }
 
         $item->description = $meta['description']['abstract'];
@@ -157,7 +161,7 @@ function rssRecentChanges(&$rss,$num,$ltype,$ns,$minor){
         $user = @$recent['user']; // the @ spares time repeating lookup
         $item->author = '';
 
-        if($user){
+        if($user && $conf['useacl'] && $auth){
             $userInfo = $auth->getUserData($user);
             $item->author = $userInfo['name'];
             if($guardmail) {
@@ -166,6 +170,10 @@ function rssRecentChanges(&$rss,$num,$ltype,$ns,$minor){
             }else{
                 $item->authorEmail = $userInfo['mail'];
             }
+        }elseif($user){
+            // this happens when no ACL but some Apache auth is used
+            $item->author      = $user;
+            $item->authorEmail = $user.'@'.$recent['ip'];
         }else{
             $item->authorEmail = 'anonymous@'.$recent['ip'];
         }
@@ -201,7 +209,7 @@ function rssListNamespace(&$rss,$ns){
             $item->title = $id;
         }
 
-        $item->link        = wl($id,'rev='.$date,true);
+        $item->link        = wl($id,'rev='.$date,true,'&');
         $item->description = $meta['description']['abstract'];
         $item->date        = date('r',$date);
         $rss->addItem($item);
