@@ -4,10 +4,8 @@
  * ---------
  * Author: M. Uli Kusterer (witness.of.teachtext@gmx.net)
  * Copyright: (c) 2004 M. Uli Kusterer, Nigel McNie (http://qbnz.com/highlighter/)
- * Release Version: 1.0.7.7
- * CVS Revision Version: $Revision: 1.8 $
+ * Release Version: 1.0.7.19
  * Date Started: 2004/06/04
- * Last Modified: $Date: 2006/02/25 00:46:33 $
  *
  * C for Macs language file for GeSHi.
  *
@@ -40,7 +38,7 @@
  ************************************************************************************/
 
 $language_data = array (
-	'LANG_NAME' => 'C',
+	'LANG_NAME' => 'C (Mac)',
 	'COMMENT_SINGLE' => array(1 => '//', 2 => '#'),
 	'COMMENT_MULTI' => array('/*' => '*/'),
 	'CASE_KEYWORDS' => GESHI_CAPS_NO_CHANGE,
@@ -173,4 +171,4 @@ $language_data = array (
 		)
 );
 
-?>
\ No newline at end of file
+?>
