@@ -2,12 +2,10 @@
 /*************************************************************************************
  * java.php
  * --------
- * Author: Nigel McNie (oracle.shinoda@gmail.com)
+ * Author: Nigel McNie (nigel@geshi.org)
  * Copyright: (c) 2004 Nigel McNie (http://qbnz.com/highlighter/)
- * Release Version: 1.0.7.7
- * CVS Revision Version: $Revision: 1.14 $
+ * Release Version: 1.0.7.19
  * Date Started: 2004/07/10
- * Last Modified: $Date: 2006/02/25 00:46:33 $
  *
  * Java language file for GeSHi.
  *
@@ -1371,7 +1369,7 @@ $language_data = array (
 	'URLS' => array(
 		1 => '',
 		2 => '',
-		3 => 'http://www.google.com/search?q=allinurl%3A{FNAME}+java.sun.com&amp;bntl=1',
+		3 => 'http://www.google.com/search?hl=en&amp;q=allinurl%3A{FNAME}+java.sun.com&amp;bntI=I%27m%20Feeling%20Lucky',
 		4 => ''
 		),
 	'OOLANG' => true,
@@ -1387,4 +1385,4 @@ $language_data = array (
 		)
 );
 
-?>
\ No newline at end of file
+?>
