@@ -4,10 +4,8 @@
  * ----------------
  * Author: Roberto Armellin (r.armellin@tin.it)
  * Copyright: (c) 2004 Roberto Armellin, Nigel McNie (http://qbnz.com/highlighter/)
- * Release Version: 1.0.7.7
- * CVS Revision Version: $Revision: 1.8 $
+ * Release Version: 1.0.7.19
  * Date Started: 2004/09/17
- * Last Modified: 2004/09/18
  *
  * Visual FoxPro language file for GeSHi.
  *
@@ -42,7 +40,7 @@
  ************************************************************************************/
 
 $language_data = array (
-	'LANG_NAME' => 'VFP',
+	'LANG_NAME' => 'Visual Fox Pro',
 	'COMMENT_SINGLE' => array(1 => "//", 2 => "\n*"),
 	'COMMENT_MULTI' => array(),
 	'CASE_KEYWORDS' => GESHI_CAPS_NO_CHANGE,
@@ -402,7 +400,7 @@ $language_data = array (
 			),
 		'COMMENTS' => array(
 			1 => 'color: green; font-style: italic;',
-			2 => 'color: green font-style: italic;',
+			2 => 'color: green; font-style: italic;',
 			'MULTI' => 'color: #808080; font-style: italic;'
 			),
 		'ESCAPE_CHAR' => array(
@@ -441,4 +439,4 @@ $language_data = array (
 		)
 );
 
-?>
\ No newline at end of file
+?>
