@@ -6,9 +6,9 @@
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
 
-  if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../').'/');
-
-  require_once(DOKU_INC.'inc/parserutils.php');
+if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../').'/');
+if(!defined('NL')) define('NL',"\n");
+require_once(DOKU_INC.'inc/parserutils.php');
 
 /**
  * Convenience function to quickly build a wikilink
@@ -41,7 +41,8 @@ function html_attbuild($attributes){
 /**
  * The loginform
  *
- * @author Andreas Gohr <andi@splitbrain.org>
+ * @author   Andreas Gohr <andi@splitbrain.org>
+ * @triggers HTML_LOGINFORM_INJECTION
  */
 function html_login(){
   global $lang;
@@ -67,6 +68,12 @@ function html_login(){
           <span><?php echo $lang['pass']?></span>
           <input type="password" name="p" class="edit" />
         </label><br />
+
+        <?php //bad and dirty event insert hook
+        $evdata = array();
+        trigger_event('HTML_LOGINFORM_INJECTION', $evdata);
+        ?>
+
         <label for="remember__me" class="simple">
           <input type="checkbox" name="r" id="remember__me" value="1" />
           <span><?php echo $lang['remember']?></span>
@@ -155,36 +162,6 @@ function html_topbtn(){
   return $ret;
 }
 
-/**
- * Just the back to media window button in its own form
- *
- * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
- */
-function html_backtomedia_button($params,$akey=''){
-  global $conf;
-  global $lang;
-
-  $ret = '<form class="button" method="get" action="'.DOKU_BASE.'lib/exe/mediamanager.php"><div class="no">';
-
-  reset($params);
-  while (list($key, $val) = each($params)) {
-    $ret .= '<input type="hidden" name="'.$key.'" ';
-    $ret .= 'value="'.htmlspecialchars($val).'" />';
-  }
-
-  $ret .= '<input type="submit" value="'.htmlspecialchars($lang['btn_backtomedia']).'" class="button" ';
-  $tit = htmlspecialchars($lang['btn_backtomedia']);
-  if($akey){
-    $tit .= ' [ALT+'.strtoupper($akey).']';
-    $ret .= 'accesskey="'.$akey.'" ';
-  }
-  $ret .= 'title="'.$tit.'" ';
-  $ret .= '/>';
-  $ret .= '</div></form>';
-
-  return $ret;
-}
-
 /**
  * Displays a button (using its own form)
  * If tooltip exists, the access key tooltip is replaced.
@@ -362,11 +339,11 @@ function html_search(){
   }
 
   //show progressbar
-  print '<div class="centeralign" id="dw__loading">';
-  print '<script type="text/javascript" charset="utf-8">';
-  print 'showLoadBar();';
-  print '</script>';
-  print "<br /></div>\n";
+  print '<div class="centeralign" id="dw__loading">'.NL;
+  print '<script type="text/javascript" charset="utf-8"><!--//--><![CDATA[//><!--'.NL;
+  print 'showLoadBar();'.NL;
+  print '//--><!]]></script>'.NL;
+  print '<br /></div>'.NL;
   flush();
 
   //do quick pagesearch
@@ -410,9 +387,9 @@ function html_search(){
   }
 
   //hide progressbar
-  print '<script type="text/javascript" charset="utf-8">';
-  print 'hideLoadBar("dw__loading");';
-  print '</script>';
+  print '<script type="text/javascript" charset="utf-8"><!--//--><![CDATA[//><!--'.NL;
+  print 'hideLoadBar("dw__loading");'.NL;
+  print '//--><!]]></script>'.NL;
   flush();
 }
 
@@ -469,7 +446,7 @@ function html_revisions($first=0){
   print p_locale_xhtml('revisions');
   print '<ul>';
   if($INFO['exists'] && $first==0){
-    print (isset($INFO['meta']) && isset($INFO['meta']['last_change']) && $INFO['meta']['last_change']['type']==='e') ? '<li class="minor">' : '<li>';
+    print (isset($INFO['meta']) && isset($INFO['meta']['last_change']) && $INFO['meta']['last_change']['type']===DOKU_CHANGE_TYPE_MINOR_EDIT) ? '<li class="minor">' : '<li>';
     print '<div class="li">';
 
     print $date;
@@ -481,7 +458,7 @@ function html_revisions($first=0){
     print ' &ndash; ';
     print $INFO['sum'];
     print ' <span class="user">';
-    print $INFO['editor'];
+    print (empty($INFO['editor']))?('('.$lang['external_edit'].')'):$INFO['editor'];
     print '</span> ';
 
     print '('.$lang['current'].')';
@@ -493,7 +470,7 @@ function html_revisions($first=0){
     $date = date($conf['dformat'],$rev);
     $info = getRevisionInfo($ID,$rev,true);
 
-    print ($info['type']==='e') ? '<li class="minor">' : '<li>';
+    print ($info['type']===DOKU_CHANGE_TYPE_MINOR_EDIT) ? '<li class="minor">' : '<li>';
     print '<div class="li">';
     print $date;
 
@@ -579,7 +556,7 @@ function html_recent($first=0){
 
   foreach($recents as $recent){
     $date = date($conf['dformat'],$recent['date']);
-    print ($recent['type']==='e') ? '<li class="minor">' : '<li>';
+    print ($recent['type']===DOKU_CHANGE_TYPE_MINOR_EDIT) ? '<li class="minor">' : '<li>';
     print '<div class="li">';
 
     print $date.' ';
@@ -677,9 +654,9 @@ function html_list_index($item){
   $base = ':'.$item['id'];
   $base = substr($base,strrpos($base,':')+1);
   if($item['type']=='d'){
-    $ret .= '<a href="'.wl($ID,'idx='.$item['id']).'" class="idx_dir">';
+    $ret .= '<a href="'.wl($ID,'idx='.$item['id']).'" class="idx_dir"><strong>';
     $ret .= $base;
-    $ret .= '</a>';
+    $ret .= '</strong></a>';
   }else{
     $ret .= html_wikilink(':'.$item['id']);
   }
@@ -758,17 +735,10 @@ function html_buildlist($data,$class,$func,$lifunc='html_li_default'){
     $level = $item['level'];
 
     //print item
-    if(is_array($lifunc)){
-      $ret .= $lifunc[0]->$lifunc[1]($item); //user object method
-    }else{
-      $ret .= $lifunc($item); //user function
-    }
+    $ret .= call_user_func($lifunc,$item);
     $ret .= '<div class="li">';
-    if(is_array($func)){
-      $ret .= $func[0]->$func[1]($item); //user object method
-    }else{
-    $ret .= $func($item); //user function
-    }
+
+    $ret .= call_user_func($func,$item);
     $ret .= '</div>';
   }
 
@@ -823,11 +793,18 @@ function html_diff($text='',$intro=true){
               $lang['current'];
     $right = $lang['yours'];
   }else{
+    //check if current revision exist
+    if(!@file_exists(wikiFN($ID))){
+      $revs = getRevisions($ID, 0, 2);
+      $rc = $revs[1];
+    }
     if($REV){
       $r = $REV;
     }else{
-      //use last revision if none given
-      $revs = getRevisions($ID, 0, 1);
+      if(empty($revs)){
+        //use last revision if none given
+        $revs = getRevisions($ID, 0, 1);
+      }
       $r = $revs[0];
     }
 
@@ -835,7 +812,7 @@ function html_diff($text='',$intro=true){
       $df  = new Diff(explode("\n",htmlspecialchars(rawWiki($ID,$r))),
                       explode("\n",htmlspecialchars(rawWiki($ID,''))));
       $left  = '<a class="wikilink1" href="'.wl($ID,"rev=$r").'">'.
-                $ID.' '.date($conf['dformat'],$r).'</a>';
+                $ID.' '.date($conf['dformat'],(isset($rc) ? $rc : $r)).'</a>';
     }else{
       $df  = new Diff(array(''),
                       explode("\n",htmlspecialchars(rawWiki($ID,''))));
@@ -843,7 +820,7 @@ function html_diff($text='',$intro=true){
                 $ID.'</a>';
     }
     $right = '<a class="wikilink1" href="'.wl($ID).'">'.
-              $ID.' '.date($conf['dformat'],@filemtime(wikiFN($ID))).'</a> '.
+              $ID.' '.date($conf['dformat'],(isset($rc) ? $r : @filemtime(wikiFN($ID)))).'</a> '.
               $lang['current'];
   }
   $tdf = new TableDiffFormatter();
@@ -909,6 +886,7 @@ function html_msgarea(){
  * Prints the registration form
  *
  * @author Andreas Gohr <andi@splitbrain.org>
+ * @triggers HTML_REGISTERFORM_INJECTION
  */
 function html_register(){
   global $lang;
@@ -952,6 +930,10 @@ function html_register(){
       <?php echo $lang['email']?>
       <input type="text" name="email" class="edit" size="50" value="<?php echo formText($_POST['email'])?>" />
     </label><br />
+    <?php //bad and dirty event insert hook
+    $evdata = array();
+    trigger_event('HTML_REGISTERFORM_INJECTION', $evdata);
+    ?>
     <input type="submit" class="button" value="<?php echo $lang['register']?>" />
   </fieldset>
   </form>
@@ -1015,7 +997,10 @@ function html_updateprofile(){
       <input type="password" name="oldpass" class="edit" size="50" />
     </label><br />
     <?php } ?>
-
+    <?php //bad and dirty event insert hook
+    $evdata = array();
+    trigger_event('HTML_PROFILEFORM_INJECTION', $evdata);
+    ?>
     <input type="submit" class="button" value="<?php echo $lang['btn_save']?>" />
     <input type="reset" class="button" value="<?php echo $lang['btn_reset']?>" />
   </fieldset>
@@ -1029,6 +1014,7 @@ function html_updateprofile(){
  *
  * @fixme    this is a huge lump of code and should be modularized
  * @triggers HTML_PAGE_FROMTEMPLATE
+ * @triggers HTML_EDITFORM_INJECTION
  * @author   Andreas Gohr <andi@splitbrain.org>
  */
 function html_edit($text=null,$include='edit'){ //FIXME: include needed?
@@ -1096,10 +1082,10 @@ function html_edit($text=null,$include='edit'){ //FIXME: include needed?
       target="_blank"><?php echo $lang['mediaselect'] ?></a><?php }?></div>
 
       <?php if($wr){?>
-      <script type="text/javascript" charset="utf-8">
+      <script type="text/javascript" charset="utf-8"><!--//--><![CDATA[//><!--
         <?php /* sets changed to true when previewed */?>
         textChanged = <?php ($pr) ? print 'true' : print 'false' ?>;
-      </script>
+      //--><!]]></script>
       <span id="spell__action"></span>
       <div id="spell__suggest"></div>
       <?php } ?>
@@ -1117,6 +1103,11 @@ function html_edit($text=null,$include='edit'){ //FIXME: include needed?
 
     <textarea name="wikitext" id="wiki__text" <?php echo $ro?> cols="80" rows="10" class="edit" tabindex="1"><?php echo "\n".formText($text)?></textarea>
 
+    <?php //bad and dirty event insert hook
+    $evdata = array('writable' => $wr);
+    trigger_event('HTML_EDITFORM_INJECTION', $evdata);
+    ?>
+
     <div id="wiki__editbar">
       <div id="size__ctl"></div>
       <?php if($wr){?>
@@ -1256,6 +1247,7 @@ function html_debug(){
 
 function html_admin(){
   global $ID;
+  global $INFO;
   global $lang;
   global $conf;
 
@@ -1266,6 +1258,10 @@ function html_admin(){
   $menu = array();
   foreach ($pluginlist as $p) {
     if($obj =& plugin_load('admin',$p) === NULL) continue;
+
+    // check permissions
+    if($obj->forAdminOnly() && !$INFO['isadmin']) continue;
+
     $menu[] = array('plugin' => $p,
                     'prompt' => $obj->getMenuText($conf['lang']),
                     'sort' => $obj->getMenuSort()
