@@ -5,10 +5,11 @@
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author     Reidar Mosvold <Reidar.Mosvold@hit.no>
  * @author     Jorge Barrera Grandon <jorge@digitalwolves.org>
+ * @author     Rune Rasmussen http://www.syntaxerror.no/
  */
 $lang['encoding']   = 'utf-8';
 $lang['direction']  = 'ltr';
- 
+
 $lang['btn_edit']   = 'Rediger denne siden';
 $lang['btn_source'] = 'Vis kildetekst';
 $lang['btn_show']   = 'Vis siden';
@@ -35,17 +36,28 @@ $lang['btn_backlink']    = "Tilbakelinker";
 $lang['btn_backtomedia'] = 'Tilbake til valg av mediafil';
 $lang['btn_subscribe']   = 'Abonner på endringer';
 $lang['btn_unsubscribe'] = 'Ikke abonner på endringer';
- 
-$lang['loggedinas'] = 'Logg inn som';
+$lang['btn_profile']     = 'Oppdater profil';
+$lang['btn_reset']       = 'Tilbakestill';
+$lang['btn_resendpwd']   = 'Send nytt passord';
+$lang['btn_draft']    = 'Rediger kladd';
+$lang['btn_recover']  = 'Gjennvinn kladd';
+$lang['btn_draftdel'] = 'Slett kladd';
+
+$lang['loggedinas'] = 'Innlogget som';
 $lang['user']       = 'Brukernavn';
 $lang['pass']       = 'Passord';
+$lang['newpass']    = 'Nytt passord';
+$lang['oldpass']    = 'Bekreft gjeldende passord';
 $lang['passchk']    = 'Bekreft passord';
-$lang['remember']   = 'Husk på meg';
-$lang['fullname']   = 'Fulle navn';
-$lang['email']      = 'E-Post';
+$lang['remember']   = 'Husk meg';
+$lang['fullname']   = 'Fullt navn';
+$lang['email']      = 'E-post';
 $lang['register']   = 'Registrer deg';
+$lang['profile']    = 'Brukerprofil';
 $lang['badlogin']   = 'Ugyldig brukernavn og/eller passord.';
- 
+$lang['minoredit']  = 'Mindre endringer';
+$lang['draftdate']  = 'Kladd autlagret'; // full dformat date will be added
+
 $lang['regmissing'] = 'Vennligst fyll ut alle felt.';
 $lang['reguexists'] = 'Det finnes allerede en konto med dette brukernavnet.';
 $lang['regsuccess'] = 'Brukerkonto har blitt laget og passord har blitt sendt via e-post.';
@@ -55,19 +67,32 @@ $lang['regbadmail'] = 'Den angitte e-post adressen ser ut til å være ugyldig.
 $lang['regbadpass'] = 'De to angitte passordene er ikke like, vennligst forsøk igjen.';
 $lang['regpwmail']  = 'Ditt DokuWiki passord';
 $lang['reghere']    = 'Har du ikke en konto enda? Lag deg en';
- 
+
+$lang['profna']       = 'Denne wikien støtter ikke profilendringer';
+$lang['profnochange'] = 'Ingen endringer, ingenting å gjøre.';
+$lang['profnoempty']  = 'Tomt navn- eller e-postfelt er ikke tillatt.';
+$lang['profchanged']  = 'Brukerprofil ble vellykket oppdatert.';
+
+$lang['pwdforget'] = 'Glemt ditt passord? Få deg et nytt';
+$lang['resendna']  = 'Denne wikien støtter ikke nyutsending.';
+$lang['resendpwd'] = 'Send nytt passord for';
+$lang['resendpwdmissing'] = 'Beklager, du må fylle inn alle felt.';
+$lang['resendpwdnouser']  = 'Beklager, vi kan ikke finne denne brukeren i vår database.';
+$lang['resendpwdbadauth'] = 'Beklager, denne autorisasjonskoden er ikke gyldig. Sjekk at du brukte hele bekreftelseslenken.';
+$lang['resendpwdconfirm'] = 'En bekreftelseslenke er blitt sendt på e-post.';
+$lang['resendpwdsuccess'] = 'Ditt nye passord er blitt sendt på e-post.';
+
 $lang['txt_upload']   = 'Velg fil som skal lastes opp';
 $lang['txt_filename'] = 'Skriv inn wikinavn (alternativt)';
 $lang['txt_overwrt']  = 'Overskriv eksisterende fil';
 $lang['lockedby']     = 'Stengt av';
 $lang['lockexpire']   = 'Avstengningen opphører';
 $lang['willexpire']   = 'Din redigeringslås for dette dokumentet kommer snart til å opphøre.\nFor å unngå versjonskonflikter bør du forhåndsvise dokumentet ditt for å forlenge redigeringslåsen.';
- 
+
 $lang['notsavedyet'] = 'Ulagrede endringer vil gå tapt.\nVil du fortsette?';
- 
 $lang['rssfailed']   = 'En feil oppstod da denne kilden skulle hentes:';
 $lang['nothingfound']= 'Ingen data funnet.';
- 
+
 $lang['mediaselect'] = 'Valg av mediafil';
 $lang['fileupload']  = 'Mediafil Opplasting';
 $lang['uploadsucc']  = 'Opplastingen var vellykket';
@@ -79,11 +104,19 @@ $lang['deletefail']  = '"%s" kunne ikke slettes - sjekk rettighetene.';
 $lang['mediainuse']  = 'Filen "%s" har ikke biltt slettet - den er fortsatt i bruk.';
 $lang['namespaces']  = 'sidenavn';
 $lang['mediafiles']  = 'Tilgjengelige filer i';
- 
+
+$lang['js']['keepopen']    = 'Hold vindu åpen ved valg';
+$lang['js']['hidedetails'] = 'Skjul detaljer';
+$lang['mediausage']  = 'Bruk følgende syntaks til å refferer til denne filen:';
+$lang['mediaview']   = 'Vis original fil';
+$lang['mediaroot']   = 'rot';
+$lang['mediaupload'] = 'Last opp en fil til gjeldende navnerom her. For å opprette undernavnerom, før dem opp før filnavn i "Last opp som" adskilt med komma.';
+$lang['mediaextchange'] = 'Filendelse endret fra .%s til .%s!';
+
 $lang['reference']   = 'Referanser for';
 $lang['ref_inuse']   = 'Denne filen kan ikke slettes fordi den er fortsatt i bruk av følgende sider:';
 $lang['ref_hidden']  = 'Noen referanser er på sider du ikke har tilgang til å lese';
- 
+
 $lang['hits']       = 'Treff';
 $lang['quickhits']  = 'Matchende wikinavn';
 $lang['toc']        = 'Innholdsfortegnelse';
@@ -92,18 +125,20 @@ $lang['yours']      = 'Din versjon';
 $lang['diff']       = 'Vis forskjeller mot nåværende versjon';
 $lang['line']       = 'Linje';
 $lang['breadcrumb'] = 'Spor';
+$lang['youarehere'] = 'Du er her';
 $lang['lastmod']    = 'Sist modifisert';
 $lang['by']         = 'av';
 $lang['deleted']    = 'fjernet';
 $lang['created']    = 'opprettet';
 $lang['restored']   = 'gjenopprettet til en tidligere versjon';
 $lang['summary']    = 'Redigeringskommentar';
- 
+
 $lang['mail_newpage'] = 'side lagt til:';
 $lang['mail_changed'] = 'side endret:';
- 
-$lang['nosmblinks'] = 'Lenker til Windowsressurser fungerer bare i Microsoft sin Internet Explorer.\nDu kan fortsatt kopiere og lime inn lenken.';
- 
+$lang['mail_new_user'] = 'Ny bruker:';
+
+$lang['nosmblinks'] = 'Lenker til Windows-ressurser fungerer bare i Microsoft sin Internet Explorer.\nDu kan fortsatt kopiere og lime inn lenken.';
+
 $lang['qb_alert']   = 'Vennligst skriv inn teksten du ønsker å formatere.\nDen vil bli lagt til mot slutten av dokumentet.';
 $lang['qb_bold']    = 'Fet tekst';
 $lang['qb_italic']  = 'Kursiv tekst';
@@ -122,7 +157,9 @@ $lang['qb_ol']      = 'Punkt for sortert punktliste';
 $lang['qb_ul']      = 'Punkt for usortert punktliste';
 $lang['qb_media']   = 'Legg til bilder og andre filer';
 $lang['qb_sig']     = 'Føy til signatur';
- 
+$lang['qb_smileys'] = 'Humørfjes';
+$lang['qb_chars']   = 'Spesialtegn';
+
 $lang['del_confirm']= 'Slett denne oppføringen?';
 $lang['admin_register']= 'Legg til ny bruker';
 
@@ -132,7 +169,7 @@ $lang['spell_wait']  = 'Vennligst vent...';
 $lang['spell_noerr'] = 'Ingen feil funnet';
 $lang['spell_nosug'] = 'Ingen forslag';
 $lang['spell_change']= 'Endre';
- 
+
 $lang['metaedit']    = 'Rediger Metadata';
 $lang['metasaveerr'] = 'Skriving av metadata feilet';
 $lang['metasaveok']  = 'Metadata lagret';
@@ -143,15 +180,47 @@ $lang['img_date']    = 'Dato';
 $lang['img_fname']   = 'Filnavn';
 $lang['img_fsize']   = 'Størrelse';
 $lang['img_artist']  = 'Fotograf';
-$lang['img_copyr']   = 'Copyright';
+$lang['img_copyr']   = 'Kopirett';
 $lang['img_format']  = 'Format';
 $lang['img_camera']  = 'Kamera';
 $lang['img_keywords']= 'Nøkkelord';
- 
+
 $lang['subscribe_success']  = 'La til %s som abonnent av listen for %s';
 $lang['subscribe_error']    = 'En feil oppstod når %s skulle legges til som abonnent av listen for %s';
 $lang['subscribe_noaddress']= 'Det er ingen adresse som er assosiert med din login. Du kan dermed ikke bli lagt til som abonnent av listen.';
 $lang['unsubscribe_success']= 'Fjernet %s som abonnent for listen %s';
 $lang['unsubscribe_error']  = 'En feil oppstod når %s skulle fjernes som abonnent fra listen for %s';
 
+/* auth.class language support */
+$lang['authmodfailed']   = 'Dårlig konfigurert brukerautorisasjon. Vennligst innformer Wiki-admin.';
+$lang['authtempfail']    = 'Brukerautorisasjon er midlertidig utilgjengelig. Om dette vedvarer, vennligst informer Wiki-admin.';
+
+/* installer strings */
+$lang['i_chooselang'] = 'Velg ditt språk';
+$lang['i_installer']  = 'DokuWiki-installasjon';
+$lang['i_wikiname']   = 'Wikinavn';
+$lang['i_enableacl']  = 'Aktiver ACL (anbefalt)';
+$lang['i_superuser']  = 'Superbruker';
+$lang['i_problems']   = 'Installasjonen oppdaget noen problemer, disse listes nedenfor. Du kan ikke fortsett før du har løst disse.';
+$lang['i_modified']   = 'For sikkerhets skyld vil dette skriptet bare virke med en ny og uendret Dokuwiki-installsjon.
+                         Du burde enten pakke ut filene på nytt fra den nedlastede pakken, eller konsultere den komplette
+                         <a href="http://wiki.splitbrain.org/wiki:install">Dokuwiki-installasjonsinstruksen</a>';
+$lang['i_funcna']     = 'PHP-funksjonen <code>%s</code> er ikke tilgjengelig. Kanskje din leverandør har deaktivert den av noen grunn?';
+$lang['i_phpver']     = 'Your PHP version <code>%s</code> is lower than the needed <code>%s</code>. You need to upgrade your PHP install.';
+$lang['i_permfail']   = '<code>%s</code> er ikke skrivbar for DokuWiki. Du behøver å fikse rettighetene for denne mappen!';
+$lang['i_confexists'] = '<code>%s</code> eksisterer allerede';
+$lang['i_writeerr']   = 'Kunne ikke opprette <code>%s</code>. Du må sjekke mappe-/filrettigheter og opprette filen manuelt.';
+$lang['i_badhash']    = 'ikke gjennkjent eller modifisert dokuwiki.php (hash=<code>%s</code>)';
+$lang['i_badval']     = '<code>%s</code> - ugyldig eller tom verdi';
+$lang['i_success']    = 'Konfigurasjonen ble vellykket fullført. Du kan slette install.php filen nå. Fortsett til
+                        <a href="doku.php">din nye DokuWiki</a>.';
+$lang['i_failure']    = 'Noen feil oppstod ved skriving til konfigurasjonsfilene. Du må kanskje fikse de manuelt før
+                         du kan bruke <a href="doku.php">din nye DokuWiki</a>.';
+$lang['i_policy']     = 'Innledende ACL-politikk';
+$lang['i_pol0']       = 'Åpen Wiki (les, skriv og opplasting for alle)';
+$lang['i_pol1']       = 'Offentlig Wiki (les for alle, skriving og opplasting bare for registrerte brukere)';
+$lang['i_pol2']       = 'Lukket Wiki (les, skriv og opplasting bare for registrerte brukere)';
+
+$lang['i_retry']      = 'Prøv igjen';
+
 //Setup VIM: ex: et ts=2 enc=utf-8 :
