@@ -7,6 +7,10 @@
  */
 $lang['encoding']     = 'utf-8';
 $lang['direction']    = 'ltr';
+$lang['doublequoteopening']  = '“';//&ldquo;
+$lang['doublequoteclosing']  = '”';//&rdquo;
+$lang['singlequoteopening']  = '‘';//&lsquo;
+$lang['singlequoteclosing']  = '’';//&rsquo;
 
 $lang['btn_edit']     = 'Editar Página';
 $lang['btn_source']   = 'Ver em bruto';
