@@ -6,9 +6,15 @@
  * @author     Yuri Pimenov <up@ftpsearch.lv>
  * @author      Igor Tarasov <tigr@mail15.com>
  * @author      Denis Simakov <akinoame1@gmail.com>
+ * @author      Kaens Bard <kaens@mail.ru>
  */
 $lang['encoding']   = 'utf-8';
 $lang['direction']  = 'ltr';
+$lang['doublequoteopening']  = '«';//&ldquo;
+$lang['doublequoteclosing']  = '»';//&rdquo;
+$lang['singlequoteopening']  = '„';//&lsquo;
+$lang['singlequoteclosing']  = '“';//&rsquo;
+$lang['apostrophe']          = '’';//&rsquo;
 
 $lang['btn_edit']   = 'Править страницу';
 $lang['btn_source'] = 'Показать исходный текст';
@@ -56,20 +62,20 @@ $lang['register']   = 'Зарегистрироваться';
 $lang['profile']    = 'Профиль пользователя';
 $lang['badlogin']   = 'Извините, неверное имя пользователя или пароль.';
 $lang['minoredit']  = 'Небольшие изменения';
-$lang['draftdate']  = 'Черновик сохранен'; // full dformat date will be added
+$lang['draftdate']  = 'Черновик сохранён'; // full dformat date will be added
 
 $lang['regmissing'] = 'Извините, вам следует заполнить все поля.';
 $lang['reguexists'] = 'Извините, пользователь с таким логином уже существует.';
 $lang['regsuccess'] = 'Пользователь создан, пароль выслан на e-mail.';
 $lang['regsuccess2']= 'Пользователь создан.';
 $lang['regmailfail']= 'Похоже, проблема с посылкой пароля по почте. Пожалуйста, сообщите администратору!';
-$lang['regbadmail'] = 'Данный вами адрес e-mail выглядит неправильным. Если вы считаете это ошибкой, сообщите админу.';
+$lang['regbadmail'] = 'Данный Вами адрес e-mail выглядит неправильным. Если вы считаете это ошибкой, сообщите админу.';
 $lang['regbadpass'] = 'Два введённых пароля не идентичны. Пожалуйста, попробуйте ещё раз.';
 $lang['regpwmail']  = 'Ваш пароль для системы DokuWiki';
-$lang['reghere']    = 'У вас еще нет аккаунта? Извольте получить';
+$lang['reghere']    = 'У вас ещё нет аккаунта? Извольте получить';
 
 $lang['profna']       = 'Данная вики не поддерживает изменение профиля';
-$lang['profnochange'] = 'Изменений не внесено, профиль не обновлён.';
+$lang['profnochange'] = 'Изменений не было внесено, профиль не обновлён.';
 $lang['profnoempty']  = 'Логин и адрес e-mail не могут быть пустыми.';
 $lang['profchanged']  = 'Профиль пользователя успешно обновлён.';
 
@@ -78,7 +84,7 @@ $lang['resendna']  = 'Данная вики не поддерживает пов
 $lang['resendpwd'] = 'Выслать пароль для';
 $lang['resendpwdmissing'] = 'Вы должны заполнить все поля формы.';
 $lang['resendpwdnouser']  = 'Пользователь с таким логином не обнаружен в нашей базе данных.';
-$lang['resendpwdbadauth'] = 'Извините, неверный код авторизации. Убедитесь, что вы полностью скопировали ссылку. ';
+$lang['resendpwdbadauth'] = 'Извините, неверный код авторизации. Убедитесь, что Вы полностью скопировали ссылку. ';
 $lang['resendpwdconfirm'] = 'Ссылка для подтверждения пароля была выслана по e-mail. ';
 $lang['resendpwdsuccess'] = 'Ваш новый пароль был выслан по e-mail.';
 
@@ -89,20 +95,23 @@ $lang['lockedby']     = 'В данный момент заблокирован';
 $lang['lockexpire']   = 'Блокировка истекает в';
 $lang['willexpire']   = 'Ваша блокировка редактирования этой страницы истекает в течение минуты.\nЧтобы избежать конфликтов и сбросить таймер блокировки, нажмите кнопку просмотра.';
 
-$lang['notsavedyet'] = 'Несохраненные изменения будут потеряны.\nВы действительно хотите продолжить?';
+$lang['notsavedyet'] = 'Несохранённые изменения будут потеряны.\nВы действительно хотите продолжить?';
 $lang['rssfailed']   = 'Произошла ошибка при получении следующей новостной ленты: ';
 $lang['nothingfound']= 'Ничего не найдено.';
 
 $lang['mediaselect'] = 'Выбор медиа-файла';
 $lang['fileupload']  = 'Закачка медиа-файла';
 $lang['uploadsucc']  = 'Закачка произведена успешно';
-$lang['uploadfail']  = 'Закачка не удалась. Может быть проблемы с правами доступа?';
+$lang['uploadfail']  = 'Закачка не удалась. Возможно, проблемы с правами доступа?';
 $lang['uploadwrong'] = 'В закачке отказано. Файлы с таким расширением запрещены. ';
 $lang['uploadexist'] = 'Файл с таким именем существует. Загрузка не произведена.';
+$lang['uploadbadcontent'] = 'Содержание файла не соответствует расширению %s.';
+$lang['uploadspam']  = 'Закачка заблокирована спам-фильтром.';
+$lang['uploadxss']   = 'Закачка заблокирована по соображениям безопасности.';
 $lang['deletesucc']  = 'Файл "%s" был удалён.';
 $lang['deletefail']  = 'Невозможно удалить файл "%s". Проверьте права доступа к файлу.';
-$lang['mediainuse']  = 'Файл "%s" не был удалён - файл все ещё используется.';
-$lang['namespaces']  = 'Пространства имен';
+$lang['mediainuse']  = 'Файл "%s" не был удалён - файл всё ещё используется.';
+$lang['namespaces']  = 'Пространства имён';
 $lang['mediafiles']  = 'Доступные файлы';
 
 $lang['js']['keepopen'] = 'Не закрывать окно после выбора';
@@ -115,11 +124,11 @@ $lang['mediaextchange'] = 'Расширение изменилось: с .%s н
 
 $lang['reference'] = 'Ссылки для';
 $lang['ref_inuse'] = 'Этот файл не может быть удалён, так как он используется следующими страницами:';
-$lang['ref_hidden'] = 'Некоторые ссылки находятся на страницах, на чтение которых у вас нет прав';
+$lang['ref_hidden'] = 'Некоторые ссылки находятся на страницах, на чтение которых у Вас нет прав';
 
 $lang['hits']       = 'соответствий';
 $lang['quickhits']  = 'Соответствия в названиях страниц';
-$lang['toc']        = 'Список содержимого';
+$lang['toc']        = 'Содержание';
 $lang['current']    = 'текущий';
 $lang['yours']      = 'Ваша версия';
 $lang['diff']       = 'показать отличия от текущей версии';
@@ -131,17 +140,19 @@ $lang['by']         = ' ';
 $lang['deleted']    = 'удалено';
 $lang['created']    = 'создано';
 $lang['restored']   = 'старая ревизия восстановлена';
+$lang['external_edit'] = 'внешнее изменение';
 $lang['summary']    = 'Сводка изменений';
 
-$lang['mail_newpage'] = 'Страница добавлена:';
-$lang['mail_changed'] = 'Страница изменена:';
-$lang['mail_new_user'] = 'Новый пользователь:';
+$lang['mail_newpage'] = 'страница добавлена:';
+$lang['mail_changed'] = 'страница изменена:';
+$lang['mail_new_user'] = 'новый пользователь:';
+$lang['mail_upload']   = 'файл закачан:';
 
-$lang['nosmblinks'] = 'Ссылка на сетевые каталоги Windows работает только из Интернет Эксплорера\nВы все же можете скопировать ссылку.';
+$lang['nosmblinks'] = 'Ссылка на сетевые каталоги Windows работает только из Интернет Эксплорера\nНо Вы можете скопировать ссылку.';
 
 $lang['qb_alert']   = 'Пожалуйста, введите текст, который хотите отформатировать.\nОн будет добавлен в конец документа.';
-$lang['qb_bold']    = 'Жирный шрифт';
-$lang['qb_italic']  = 'Наклонный шрифт';
+$lang['qb_bold']    = 'Полужирный шрифт';
+$lang['qb_italic']  = 'Курсивный шрифт';
 $lang['qb_underl']  = 'Подчеркивание';
 $lang['qb_code']    = 'Текст кода';
 $lang['qb_strike']  = 'Зачёркнутый шрифт';
@@ -158,7 +169,7 @@ $lang['qb_ul']      = 'Элемент ненумерованного списк
 $lang['qb_media']   = 'Добавить картинки и другие файлы';
 $lang['qb_sig']     = 'Вставить подпись';
 $lang['qb_smileys'] = 'Смайлики';
-$lang['qb_chars']   = 'Специальный символы';
+$lang['qb_chars']   = 'Специальные символы';
 
 $lang['del_confirm']= 'Вы на самом деле желаете удалить выбранное?';
 $lang['admin_register']= 'Добавить пользователя';
@@ -196,16 +207,16 @@ $lang['authmodfailed']     = 'Неправильная конфигурация
 $lang['authtempfail']      = 'Аутентификация пользователей временно недоступна. Если проблема продолжается какое-то время, пожалуйста, сообщите об этом вашему администратору вики.';
 
 /* installer strings */
-$lang['i_chooselang'] = 'Выберите ваш язык';
+$lang['i_chooselang'] = 'Выберите Ваш язык/Language';
 $lang['i_installer'] = 'Установка DokuWiki';
 $lang['i_wikiname'] = 'Название вики';
 $lang['i_enableacl'] = 'Разрешить ограничение прав доступа (рекомендуется)';
 $lang['i_superuser'] = 'Суперюзер';
 $lang['i_problems'] = 'Программа установки столкнулась с проблемами, перечисленными ниже. Чтобы продолжить, вам необходимо их устранить. ';
-$lang['i_modified'] = 'Из соображений безопасности эта программа запускается только на новой, не измененной установке DokuWiki. 
+$lang['i_modified'] = 'Из соображений безопасности эта программа запускается только на новой, неизменённой установке DokuWiki. 
                          Вам нужно либо заново распаковать скачанный пакет установки, либо обратиться к полной
                          <a href="http://wiki.splitbrain.org/wiki:install">инструкции по установке DokuWiki</a>';
-$lang['i_funcna'] = 'Функция PHP <code>%s</code> недоступна. Может быть, она по какой-то причине заблокирована вашим хостингом?';
+$lang['i_funcna'] = 'Функция PHP <code>%s</code> недоступна. Может быть, она по какой-то причине заблокирована Вашим хостингом?';
 $lang['i_phpver'] = 'Ваша версия PHP (<code>%s</code>) ниже требуемой (<code>%s</code>). Вам необходимо обновить установленную версию PHP.';
 $lang['i_permfail'] = '<code>%s</code> недоступна для записи DokuWiki. Вам необходимо исправить системные права доступа для этой директории!';
 $lang['i_confexists'] = '<code>%s</code> уже существует';
@@ -214,7 +225,7 @@ $lang['i_badhash'] = 'dokuwiki.php не распознана или измене
 $lang['i_badval'] = '<code>%s</code> - недопустимое или пустое значение';
 $lang['i_success'] = 'Конфигурация прошла успешно. Теперь вы можете удалить файл install.php. Переходите к
                         <a href="doku.php">вашей новой DokuWiki</a>.';
-$lang['i_failure'] = 'При записи в файлы конфигурации были обнаружены ошибки. Возможно, вам придется исправить их вручную, прежде, чем вы сможете использовать <a href="doku.php">вашу новую DokuWiki</a>.';
+$lang['i_failure'] = 'При записи в файлы конфигурации были обнаружены ошибки. Возможно, вам придется исправить их вручную, прежде чем вы сможете использовать <a href="doku.php">Вашу новую DokuWiki</a>.';
 $lang['i_policy'] = 'Исходная политика прав доступа';
 $lang['i_pol0'] = 'Открытая вики (чтение, запись, закачка файлов для всех)';
 $lang['i_pol1'] = 'Общедоступная вики (чтение для всех, запись и загрузка файлов для зарегистрированных пользователей)';
