@@ -21,7 +21,7 @@
 function getID($param='id',$clean=true){
   global $conf;
 
-  $id = $_REQUEST[$param];
+  $id = isset($_REQUEST[$param]) ? $_REQUEST[$param] : null;
 
   //construct page id from request URI
   if(empty($id) && $conf['userewrite'] == 2){
@@ -52,6 +52,25 @@ function getID($param='id',$clean=true){
     //strip leading slashes
     $id = preg_replace('!^/+!','',$id);
   }
+
+  // Namespace autolinking from URL
+  if(substr($id,-1) == ':' || ($conf['useslash'] && substr($id,-1) == '/')){
+    if(@file_exists(wikiFN($id.$conf['start']))){
+      // start page inside namespace
+      $id = $id.$conf['start'];
+    }elseif(@file_exists(wikiFN($id.noNS(cleanID($id))))){
+      // page named like the NS inside the NS
+      $id = $id.noNS(cleanID($id));
+    }elseif(@file_exists(wikiFN($id))){
+      // page like namespace exists
+      $id = substr($id,0,-1);
+    }else{
+      // fall back to default
+      $id = $id.$conf['start'];
+    }
+    header("Location: ".wl($id,'',true));
+  }
+
   if($clean) $id = cleanID($id);
   if(empty($id) && $param=='id') $id = $conf['start'];
 
@@ -65,19 +84,27 @@ function getID($param='id',$clean=true){
  * converted to unaccented ones
  *
  * @author Andreas Gohr <andi@splitbrain.org>
- * @param  string  $id    The pageid to clean
- * @param  boolean $ascii Force ASCII
+ * @param  string  $raw_id    The pageid to clean
+ * @param  boolean $ascii     Force ASCII
  */
-function cleanID($id,$ascii=false){
+function cleanID($raw_id,$ascii=false){
   global $conf;
   global $lang;
   static $sepcharpat = null;
 
+  global $cache_cleanid;
+  $cache = & $cache_cleanid;
+
+  // check if it's already in the memory cache
+  if (isset($cache[$raw_id])) {
+    return $cache[$raw_id];
+    }
+
   $sepchar = $conf['sepchar'];
   if($sepcharpat == null) // build string only once to save clock cycles
     $sepcharpat = '#\\'.$sepchar.'+#';
 
-  $id = trim($id);
+  $id = trim($raw_id);
   $id = utf8_strtolower($id);
 
   //alternative namespace seperator
@@ -102,6 +129,7 @@ function cleanID($id,$ascii=false){
   $id = trim($id,':._-');
   $id = preg_replace('#:[:\._\-]+#',':',$id);
 
+  $cache[$raw_id] = $id;
   return($id);
 }
 
@@ -111,10 +139,11 @@ function cleanID($id,$ascii=false){
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function getNS($id){
- if(strpos($id,':')!==false){
-   return substr($id,0,strrpos($id,':'));
- }
- return false;
+  $pos = strrpos($id,':');
+  if($pos!==false){
+    return substr($id,0,$pos);
+  }
+  return false;
 }
 
 /**
@@ -122,8 +151,40 @@ function getNS($id){
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function noNS($id){
-  return preg_replace('/.*:/','',$id);
+function noNS($id) {
+  $pos = strrpos($id, ':');
+  if ($pos!==false) {
+    return substr($id, $pos+1);
+  } else {
+    return $id;
+  }
+}
+
+/**
+* Returns the current namespace
+*
+* @author Nathan Fritz <fritzn@crown.edu>
+*/
+function curNS($id) {
+    return noNS(getNS($id));
+}
+
+/**
+* Returns the ID without the namespace or current namespace for 'start' pages
+*
+* @author Nathan Fritz <fritzn@crown.edu>
+*/
+function noNSorNS($id) {
+    global $conf;
+
+    $p = noNS($id);
+    if ($p == $conf['start']) {
+        $p = curNS($id);
+        if ($p == false) {
+            return noNS($id);
+        }
+    }
+    return $p;
 }
 
 /**
@@ -134,22 +195,53 @@ function noNS($id){
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function wikiFN($id,$rev=''){
+function wikiFN($raw_id,$rev='',$clean=true){
   global $conf;
-  $id = cleanID($id);
+
+  global $cache_wikifn;
+  $cache = & $cache_wikifn;
+
+  if (isset($cache[$raw_id]) && isset($cache[$raw_id][$rev])) {
+    return $cache[$raw_id][$rev];
+  }
+
+  $id = $raw_id;
+
+  if ($clean) $id = cleanID($id);
   $id = str_replace(':','/',$id);
   if(empty($rev)){
     $fn = $conf['datadir'].'/'.utf8_encodeFN($id).'.txt';
   }else{
     $fn = $conf['olddir'].'/'.utf8_encodeFN($id).'.'.$rev.'.txt';
-    if($conf['usegzip'] && !@file_exists($fn)){
-      //return gzip if enabled and plaintext doesn't exist
-      $fn .= '.gz';
+    if($conf['compression']){
+      //test for extensions here, we want to read both compressions
+       if (@file_exists($fn . '.gz')){
+          $fn .= '.gz';
+       }else if(@file_exists($fn . '.bz2')){
+          $fn .= '.bz2';
+       }else{
+          //file doesnt exist yet, so we take the configured extension
+          $fn .= '.' . $conf['compression'];
+       }
     }
   }
+
+  if (!isset($cache[$raw_id])) { $cache[$raw_id] = array(); }
+  $cache[$raw_id][$rev] = $fn;
   return $fn;
 }
 
+/**
+ * Returns the full path to the file for locking the page while editing.
+ *
+ * @author Ben Coburn <btcoburn@silicodon.net>
+ */
+function wikiLockFN($id) {
+  global $conf;
+  return $conf['lockdir'].'/'.md5(cleanID($id)).'.lock';
+}
+
+
 /**
  * returns the full path to the meta file specified by ID and extension
  *
@@ -217,25 +309,59 @@ function localeFN($id){
   return $file;
 }
 
+/**
+ * Resolve relative paths in IDs
+ *
+ * Do not call directly use resolve_mediaid or resolve_pageid
+ * instead
+ *
+ * Partyly based on a cleanPath function found at
+ * http://www.php.net/manual/en/function.realpath.php#57016
+ *
+ * @author <bart at mediawave dot nl>
+ */
+function resolve_id($ns,$id,$clean=true){
+  // if the id starts with a dot we need to handle the
+  // relative stuff
+  if($id{0} == '.'){
+    // normalize initial dots without a colon
+    $id = preg_replace('/^(\.+)(?=[^:\.])/','\1:',$id);
+    // prepend the current namespace
+    $id = $ns.':'.$id;
+
+    // cleanup relatives
+    $result = array();
+    $pathA  = explode(':', $id);
+    if (!$pathA[0]) $result[] = '';
+    foreach ($pathA AS $key => $dir) {
+      if ($dir == '..') {
+        if (end($result) == '..') {
+          $result[] = '..';
+        } elseif (!array_pop($result)) {
+          $result[] = '..';
+        }
+      } elseif ($dir && $dir != '.') {
+        $result[] = $dir;
+      }
+    }
+    if (!end($pathA)) $result[] = '';
+    $id = implode(':', $result);
+  }elseif($ns !== false && strpos($id,':') === false){
+    //if link contains no namespace. add current namespace (if any)
+    $id = $ns.':'.$id;
+  }
+
+  if($clean) $id = cleanID($id);
+  return $id;
+}
+
 /**
  * Returns a full media id
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function resolve_mediaid($ns,&$page,&$exists){
-  global $conf;
-
-  //if links starts with . add current namespace
-  if($page{0} == '.'){
-    $page = $ns.':'.substr($page,1);
-  }
-
-  //if link contains no namespace. add current namespace (if any)
-  if($ns !== false && strpos($page,':') === false){
-    $page = $ns.':'.$page;
-  }
-
-  $page   = cleanID($page);
+  $page   = resolve_id($ns,$page);
   $file   = mediaFN($page);
   $exists = @file_exists($file);
 }
@@ -249,40 +375,58 @@ function resolve_pageid($ns,&$page,&$exists){
   global $conf;
   $exists = false;
 
-  //if links starts with . add current namespace
-  if($page{0} == '.'){
-    $page = $ns.':'.substr($page,1);
-  }
-
-  //if link contains no namespace. add current namespace (if any)
-  if($ns !== false && strpos($page,':') === false){
-    $page = $ns.':'.$page;
-  }
-
   //keep hashlink if exists then clean both parts
-  list($page,$hash) = split('#',$page,2);
-  $page = cleanID($page);
+  if (strpos($page,'#')) {
+    list($page,$hash) = split('#',$page,2);
+  } else {
+    $hash = '';
+  }
   $hash = cleanID($hash);
+  $page = resolve_id($ns,$page,false); // resolve but don't clean, yet
 
+  // get filename (calls clean itself)
   $file = wikiFN($page);
 
-  //check alternative plural/nonplural form
-  if(!@file_exists($file)){
-    if( $conf['autoplural'] ){
-      if(substr($page,-1) == 's'){
-        $try = substr($page,0,-1);
-      }else{
-        $try = $page.'s';
-      }
-      if(@file_exists(wikiFN($try))){
-        $page   = $try;
-        $exists = true;
-      }
+  // if ends with colon or slash we have a namespace link
+  if(substr($page,-1) == ':' || ($conf['useslash'] && substr($page,-1) == '/')){
+    if(@file_exists(wikiFN($page.$conf['start']))){
+      // start page inside namespace
+      $page = $page.$conf['start'];
+      $exists = true;
+    }elseif(@file_exists(wikiFN($page.noNS(cleanID($page))))){
+      // page named like the NS inside the NS
+      $page = $page.noNS(cleanID($page));
+      $exists = true;
+    }elseif(@file_exists(wikiFN($page))){
+      // page like namespace exists
+      $page = $page;
+      $exists = true;
+    }else{
+      // fall back to default
+      $page = $page.$conf['start'];
     }
   }else{
-    $exists = true;
+    //check alternative plural/nonplural form
+    if(!@file_exists($file)){
+      if( $conf['autoplural'] ){
+        if(substr($page,-1) == 's'){
+          $try = substr($page,0,-1);
+        }else{
+          $try = $page.'s';
+        }
+        if(@file_exists(wikiFN($try))){
+          $page   = $try;
+          $exists = true;
+        }
+      }
+    }else{
+      $exists = true;
+    }
   }
 
+  // now make sure we have a clean page
+  $page = cleanID($page);
+
   //add hash if any
   if(!empty($hash)) $page .= '#'.$hash;
 }
@@ -330,4 +474,51 @@ function isVisiblePage($id){
   return !isHiddenPage($id);
 }
 
+/**
+ * Checks and sets HTTP headers for conditional HTTP requests
+ *
+ * @author   Simon Willison <swillison@gmail.com>
+ * @link     http://simon.incutio.com/archive/2003/04/23/conditionalGet
+ * @param    timestamp $timestamp lastmodified time of the cache file
+ * @returns  void or void with previously header() commands executed
+ */
+function http_conditionalRequest($timestamp){
+  // A PHP implementation of conditional get, see
+  //   http://fishbowl.pastiche.org/archives/001132.html
+  $last_modified = substr(gmdate('r', $timestamp), 0, -5).'GMT';
+  $etag = '"'.md5($last_modified).'"';
+  // Send the headers
+  header("Last-Modified: $last_modified");
+  header("ETag: $etag");
+  // See if the client has provided the required headers
+  if (isset($_SERVER['HTTP_IF_MODIFIED_SINCE'])){
+    $if_modified_since = stripslashes($_SERVER['HTTP_IF_MODIFIED_SINCE']);
+  }else{
+    $if_modified_since = false;
+  }
+
+  if (isset($_SERVER['HTTP_IF_NONE_MATCH'])){
+    $if_none_match = stripslashes($_SERVER['HTTP_IF_NONE_MATCH']);
+  }else{
+    $if_none_match = false;
+  }
+
+  if (!$if_modified_since && !$if_none_match){
+    return;
+  }
+
+  // At least one of the headers is there - check them
+  if ($if_none_match && $if_none_match != $etag) {
+    return; // etag is there but doesn't match
+  }
+
+  if ($if_modified_since && $if_modified_since != $last_modified) {
+    return; // if-modified-since is there but doesn't match
+  }
+
+  // Nothing has changed since their last request - serve a 304 and exit
+  header('HTTP/1.0 304 Not Modified');
+  exit;
+}
+
 //Setup VIM: ex: et ts=2 enc=utf-8 :
