@@ -58,12 +58,12 @@ class Doku_Parser {
 
     var $modes = array();
 
-    var $connected = FALSE;
+    var $connected = false;
 
     function addBaseMode(& $BaseMode) {
         $this->modes['base'] = & $BaseMode;
         if ( !$this->Lexer ) {
-            $this->Lexer = & new Doku_Lexer($this->Handler,'base', TRUE);
+            $this->Lexer = & new Doku_Lexer($this->Handler,'base', true);
         }
         $this->modes['base']->Lexer = & $this->Lexer;
     }
@@ -106,7 +106,7 @@ class Doku_Parser {
             $this->modes[$mode]->postConnect();
         }
 
-        $this->connected = TRUE;
+        $this->connected = true;
     }
 
     function parse($doc) {
@@ -118,7 +118,7 @@ class Doku_Parser {
             $this->Handler->_finalize();
             return $this->Handler->calls;
         } else {
-            return FALSE;
+            return false;
         }
     }
 
@@ -197,6 +197,7 @@ class Doku_Parser_Mode_footnote extends Doku_Parser_Mode {
                 $PARSER_MODES['disabled']
             );
 
+        unset($this->allowedModes[array_search('footnote', $this->allowedModes)]);
     }
 
     function connectTo($mode) {
@@ -209,7 +210,6 @@ class Doku_Parser_Mode_footnote extends Doku_Parser_Mode {
         $this->Lexer->addExitPattern(
             '\x29\x29','footnote'
             );
-
     }
 
     function getSort() {
@@ -222,22 +222,11 @@ class Doku_Parser_Mode_header extends Doku_Parser_Mode {
 
     function preConnect() {
         //we're not picky about the closing ones, two are enough
-
-        // Header 1 is special case - match 6 or more
         $this->Lexer->addSpecialPattern(
-                            '[ \t]*={6,}[^\n]+={2,}[ \t]*(?=\n)',
+                            '[ \t]*={2,}[^\n]+={2,}[ \t]*(?=\n)',
                             'base',
                             'header'
                         );
-
-        // For the rest, match exactly
-        for ( $i = 5; $i > 1; $i--) {
-            $this->Lexer->addSpecialPattern(
-                                '[ \t]*={'.$i.'}[^\n]+={2,}[ \t]*(?=\n)',
-                                'base',
-                                'header'
-                            );
-        }
     }
 
     function getSort() {
@@ -339,19 +328,19 @@ class Doku_Parser_Mode_formatting extends Doku_Parser_Mode {
             ),
 
         'subscript'=> array (
-            'entry'=>'<sub>(?=.*\x3C/sub\x3E)',
+            'entry'=>'<sub>(?=.*</sub>)',
             'exit'=>'</sub>',
             'sort'=>110
             ),
 
         'superscript'=> array (
-            'entry'=>'<sup>(?=.*\x3C/sup\x3E)',
+            'entry'=>'<sup>(?=.*</sup>)',
             'exit'=>'</sup>',
             'sort'=>120
             ),
 
         'deleted'=> array (
-            'entry'=>'<del>(?=.*\x3C/del\x3E)',
+            'entry'=>'<del>(?=.*</del>)',
             'exit'=>'</del>',
             'sort'=>130
             ),
@@ -480,7 +469,7 @@ class Doku_Parser_Mode_table extends Doku_Parser_Mode {
 class Doku_Parser_Mode_unformatted extends Doku_Parser_Mode {
 
     function connectTo($mode) {
-        $this->Lexer->addEntryPattern('<nowiki>(?=.*\x3C/nowiki\x3E)',$mode,'unformatted');
+        $this->Lexer->addEntryPattern('<nowiki>(?=.*</nowiki>)',$mode,'unformatted');
         $this->Lexer->addEntryPattern('%%(?=.*%%)',$mode,'unformattedalt');
     }
 
@@ -499,7 +488,7 @@ class Doku_Parser_Mode_unformatted extends Doku_Parser_Mode {
 class Doku_Parser_Mode_php extends Doku_Parser_Mode {
 
     function connectTo($mode) {
-        $this->Lexer->addEntryPattern('<php>(?=.*\x3C/php\x3E)',$mode,'php');
+        $this->Lexer->addEntryPattern('<php>(?=.*</php>)',$mode,'php');
     }
 
     function postConnect() {
@@ -515,7 +504,7 @@ class Doku_Parser_Mode_php extends Doku_Parser_Mode {
 class Doku_Parser_Mode_html extends Doku_Parser_Mode {
 
     function connectTo($mode) {
-        $this->Lexer->addEntryPattern('<html>(?=.*\x3C/html\x3E)',$mode,'html');
+        $this->Lexer->addEntryPattern('<html>(?=.*</html>)',$mode,'html');
     }
 
     function postConnect() {
@@ -554,7 +543,7 @@ class Doku_Parser_Mode_preformatted extends Doku_Parser_Mode {
 class Doku_Parser_Mode_code extends Doku_Parser_Mode {
 
     function connectTo($mode) {
-        $this->Lexer->addEntryPattern('<code(?=.*\x3C/code\x3E)',$mode,'code');
+        $this->Lexer->addEntryPattern('<code(?=.*</code>)',$mode,'code');
     }
 
     function postConnect() {
@@ -570,7 +559,7 @@ class Doku_Parser_Mode_code extends Doku_Parser_Mode {
 class Doku_Parser_Mode_file extends Doku_Parser_Mode {
 
     function connectTo($mode) {
-        $this->Lexer->addEntryPattern('<file>(?=.*\x3C/file\x3E)',$mode,'file');
+        $this->Lexer->addEntryPattern('<file>(?=.*</file>)',$mode,'file');
     }
 
     function postConnect() {
@@ -624,12 +613,16 @@ class Doku_Parser_Mode_acronym extends Doku_Parser_Mode {
     }
 
     function preConnect() {
+        if(!count($this->acronyms)) return;
+
         $bound = '[\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f]';
         $acronyms = array_map('Doku_Lexer_Escape',$this->acronyms);
         $this->pattern = '(?<=^|'.$bound.')(?:'.join('|',$acronyms).')(?='.$bound.')';
     }
 
     function connectTo($mode) {
+        if(!count($this->acronyms)) return;
+
         if ( strlen($this->pattern) > 0 ) {
             $this->Lexer->addSpecialPattern($this->pattern,$mode,'acronym');
         }
@@ -651,6 +644,8 @@ class Doku_Parser_Mode_smiley extends Doku_Parser_Mode {
     }
 
     function preConnect() {
+        if(!count($this->smileys) || $this->pattern != '') return;
+
         $sep = '';
         foreach ( $this->smileys as $smiley ) {
             $this->pattern .= $sep.Doku_Lexer_Escape($smiley);
@@ -659,6 +654,8 @@ class Doku_Parser_Mode_smiley extends Doku_Parser_Mode {
     }
 
     function connectTo($mode) {
+        if(!count($this->smileys)) return;
+
         if ( strlen($this->pattern) > 0 ) {
             $this->Lexer->addSpecialPattern($this->pattern,$mode,'smiley');
         }
@@ -681,7 +678,7 @@ class Doku_Parser_Mode_wordblock extends Doku_Parser_Mode {
 
     function preConnect() {
 
-        if ( count($this->badwords) == 0 ) {
+        if ( count($this->badwords) == 0 || $this->pattern != '') {
             return;
         }
 
@@ -705,9 +702,6 @@ class Doku_Parser_Mode_wordblock extends Doku_Parser_Mode {
 }
 
 //-------------------------------------------------------------------
-/**
-* @TODO Quotes and 640x480 are not supported - just straight replacements here
-*/
 class Doku_Parser_Mode_entity extends Doku_Parser_Mode {
     // A list
     var $entities = array();
@@ -718,6 +712,8 @@ class Doku_Parser_Mode_entity extends Doku_Parser_Mode {
     }
 
     function preConnect() {
+        if(!count($this->entities) || $this->pattern != '') return;
+
         $sep = '';
         foreach ( $this->entities as $entity ) {
             $this->pattern .= $sep.Doku_Lexer_Escape($entity);
@@ -726,6 +722,8 @@ class Doku_Parser_Mode_entity extends Doku_Parser_Mode {
     }
 
     function connectTo($mode) {
+        if(!count($this->entities)) return;
+
         if ( strlen($this->pattern) > 0 ) {
             $this->Lexer->addSpecialPattern($this->pattern,$mode,'entity');
         }
@@ -757,20 +755,31 @@ class Doku_Parser_Mode_multiplyentity extends Doku_Parser_Mode {
 class Doku_Parser_Mode_quotes extends Doku_Parser_Mode {
 
     function connectTo($mode) {
+        global $conf;
+
+        $ws   =  '\s/\#~:+=&%@\-\x28\x29\]\[{}><"\'';   // whitespace
+        $punc =  ';,\.?!';
+
+        if($conf['typography'] == 2){
+            $this->Lexer->addSpecialPattern(
+                        "(?<=^|[$ws])'(?=[^$ws$punc])",$mode,'singlequoteopening'
+                    );
+            $this->Lexer->addSpecialPattern(
+                        "(?<=^|[^$ws]|[$punc])'(?=$|[$ws$punc])",$mode,'singlequoteclosing'
+                    );
+            $this->Lexer->addSpecialPattern(
+                        "(?<=^|[^$ws$punc])'(?=$|[^$ws$punc])",$mode,'apostrophe'
+                    );
+        }
 
         $this->Lexer->addSpecialPattern(
-                    '(?<=^|\s)\'(?=\S)',$mode,'singlequoteopening'
+                    "(?<=^|[$ws])\"(?=[^$ws$punc])",$mode,'doublequoteopening'
                 );
         $this->Lexer->addSpecialPattern(
-                    '(?<=^|\S)\'',$mode,'singlequoteclosing'
-                );
-        $this->Lexer->addSpecialPattern(
-                    '(?<=^|\s)"(?=\S)',$mode,'doublequoteopening'
-                );
-        $this->Lexer->addSpecialPattern(
-                    '(?<=^|\S)"',$mode,'doublequoteclosing'
+                    "\"",$mode,'doublequoteclosing'
                 );
 
+
     }
 
     function getSort() {
@@ -832,10 +841,11 @@ class Doku_Parser_Mode_rss extends Doku_Parser_Mode {
 
 //-------------------------------------------------------------------
 class Doku_Parser_Mode_externallink extends Doku_Parser_Mode {
-    var $schemes = array('http','https','telnet','gopher','wais','ftp','ed2k','irc');
+    var $schemes = array('http','https','telnet','gopher','wais','ftp','ed2k','irc','ldap');
     var $patterns = array();
 
     function preConnect() {
+        if(count($this->patterns)) return;
 
         $ltrs = '\w';
         $gunk = '/\#~:.?+=&%@!\-';
@@ -853,6 +863,7 @@ class Doku_Parser_Mode_externallink extends Doku_Parser_Mode {
     }
 
     function connectTo($mode) {
+
         foreach ( $this->patterns as $pattern ) {
             $this->Lexer->addSpecialPattern($pattern,$mode,'externallink');
         }
@@ -913,7 +924,8 @@ class Doku_Parser_Mode_windowssharelink extends Doku_Parser_Mode {
 class Doku_Parser_Mode_emaillink extends Doku_Parser_Mode {
 
     function connectTo($mode) {
-        $this->Lexer->addSpecialPattern("<[\w0-9\-_.]+?@[\w\-]+\.[\w\-\.]+\.*[\w]+>",$mode,'emaillink');
+        // pattern below is defined in inc/mail.php
+        $this->Lexer->addSpecialPattern('<'.PREG_PATTERN_VALID_EMAIL.'>',$mode,'emaillink');
     }
 
     function getSort() {
