@@ -6,21 +6,34 @@
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
 
+// plugin related constants
+if(!defined('DOKU_PLUGIN'))  define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
+$plugin_types = array('admin','syntax','action','renderer', 'helper');
 
 /**
  * Returns a list of available plugins of given type
  *
- * Returns all plugins if no type given
+ * @param $type  string, plugin_type name;
+ *               the type of plugin to return,
+ *               use empty string for all types
+ * @param $all   bool;
+ *               false to only return enabled plugins,
+ *               true to return both enabled and disabled plugins
+ *
+ * @return       array of plugin names
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function plugin_list($type=''){
+function plugin_list($type='',$all=false){
   $plugins = array();
   if ($dh = opendir(DOKU_PLUGIN)) {
     while (false !== ($plugin = readdir($dh))) {
       if ($plugin == '.' || $plugin == '..' || $plugin == 'tmp') continue;
       if (is_file(DOKU_PLUGIN.$plugin)) continue;
 
+      // if required, skip disabled plugins
+      if (!$all && plugin_isdisabled($plugin)) continue;
+
       if ($type=='' || @file_exists(DOKU_PLUGIN."$plugin/$type.php")){
           $plugins[] = $plugin;
       } else {
@@ -55,12 +68,12 @@ function &plugin_load($type,$name){
 
 
   //plugin already loaded?
-  if($DOKU_PLUGINS[$type][$name] != null){
+  if(!empty($DOKU_PLUGINS[$type][$name])){
     return $DOKU_PLUGINS[$type][$name];
   }
 
   //try to load the wanted plugin file
-  if (file_exists(DOKU_PLUGIN."$name/$type.php")){
+  if (@file_exists(DOKU_PLUGIN."$name/$type.php")){
     include_once(DOKU_PLUGIN."$name/$type.php");
   }else{
     list($plugin, $component) = preg_split("/_/",$name, 2);
@@ -69,10 +82,14 @@ function &plugin_load($type,$name){
     }
   }
 
-  //construct class and instanciate
+  //construct class and instantiate
   $class = $type.'_plugin_'.$name;
   if (!class_exists($class)) return null;
 
   $DOKU_PLUGINS[$type][$name] = new $class;
   return $DOKU_PLUGINS[$type][$name];
 }
+
+function plugin_isdisabled($name) { return @file_exists(DOKU_PLUGIN.$name.'/disabled'); }
+function plugin_enable($name) { return @unlink(DOKU_PLUGIN.$name.'/disabled'); }
+function plugin_disable($name) { return @touch(DOKU_PLUGIN.$name.'/disabled'); }
