@@ -30,10 +30,19 @@ if(!defined('SIMPLE_TEST')){
 function css_out(){
     global $conf;
     global $lang;
-    $print = (bool) $_REQUEST['print'];   //print mode?
+    switch ($_REQUEST['s']) {
+        case 'all':
+        case 'print':
+        case 'feed':
+            $style = $_REQUEST['s'];
+        break;
+        default:
+            $style = '';
+        break;
+    }
 
     // The generated script depends on some dynamic options
-    $cache = getCacheName('styles'.$conf['template'].$print,'.css');
+    $cache = getCacheName('styles'.$conf['template'].$style,'.css');
 
     // load template styles
     $tplstyles = array();
@@ -47,12 +56,13 @@ function css_out(){
     // Array of needed files and their web locations, the latter ones
     // are needed to fix relative paths in the stylesheets
     $files   = array();
-    if (isset($tplstyles['all'])) $files = array_merge($files, $tplstyles['all']);
-    if($print){
+    //if (isset($tplstyles['all'])) $files = array_merge($files, $tplstyles['all']);
+    if(!empty($style)){
+        $files[DOKU_INC.'lib/styles/'.$style.'.css'] = DOKU_BASE.'lib/styles/';
         // load plugin, template, user styles
-        $files = array_merge($files, css_pluginstyles('print'));
-        if (isset($tplstyles['print'])) $files = array_merge($files, $tplstyles['print']);
-        $files[DOKU_CONF.'userprint.css'] = '';
+        $files = array_merge($files, css_pluginstyles($style));
+        if (isset($tplstyles[$style])) $files = array_merge($files, $tplstyles[$style]);
+        $files[DOKU_CONF.'user'.$style.'.css'] = '';
     }else{
         $files[DOKU_INC.'lib/styles/style.css'] = DOKU_BASE.'lib/styles/';
         if($conf['spellchecker']){
@@ -116,6 +126,8 @@ function css_out(){
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function css_cacheok($cache,$files){
+    if($_REQUEST['purge']) return false; //support purge request
+
     $ctime = @filemtime($cache);
     if(!$ctime) return false; //There is no cache
 
@@ -135,7 +147,7 @@ function css_cacheok($cache,$files){
 }
 
 /**
- * Does placeholder replacements in the style according to 
+ * Does placeholder replacements in the style according to
  * the ones defined in a templates style.ini file
  *
  * @author Andreas Gohr <andi@splitbrain.org>
@@ -233,16 +245,22 @@ function css_loadfile($file,$location=''){
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function css_pluginstyles($mode='screen'){
+    global $lang;
     $list = array();
     $plugins = plugin_list();
     foreach ($plugins as $p){
-        if($mode == 'print'){
-            $list[DOKU_PLUGIN."$p/print.css"]  = DOKU_BASE."lib/plugins/$p/";
+        if($mode == 'all'){
             $list[DOKU_PLUGIN."$p/all.css"]  = DOKU_BASE."lib/plugins/$p/";
+        }elseif($mode == 'print'){
+            $list[DOKU_PLUGIN."$p/print.css"]  = DOKU_BASE."lib/plugins/$p/";
+        }elseif($mode == 'feed'){
+            $list[DOKU_PLUGIN."$p/feed.css"]  = DOKU_BASE."lib/plugins/$p/";
         }else{
             $list[DOKU_PLUGIN."$p/style.css"]  = DOKU_BASE."lib/plugins/$p/";
             $list[DOKU_PLUGIN."$p/screen.css"] = DOKU_BASE."lib/plugins/$p/";
-            $list[DOKU_PLUGIN."$p/all.css"]  = DOKU_BASE."lib/plugins/$p/";
+        }
+        if($lang['direction'] == 'rtl'){
+            $list[DOKU_PLUGIN."$p/rtl.css"] = DOKU_BASE."lib/plugins/$p/";
         }
     }
     return $list;
