@@ -7,6 +7,7 @@
  */
 
   if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../../').'/');
+  define('DOKU_DISABLE_GZIP_OUTPUT', 1);
   require_once(DOKU_INC.'inc/init.php');
   require_once(DOKU_INC.'inc/common.php');
   require_once(DOKU_INC.'inc/pageutils.php');
@@ -19,10 +20,10 @@
   $mimetypes = getMimeTypes();
 
   //get input
-  $MEDIA  = getID('media',false); // no cleaning - maybe external
+  $MEDIA  = stripctl(getID('media',false)); // no cleaning except control chars - maybe external
   $CACHE  = calc_cache($_REQUEST['cache']);
-  $WIDTH  = $_REQUEST['w'];
-  $HEIGHT = $_REQUEST['h'];
+  $WIDTH  = (int) $_REQUEST['w'];
+  $HEIGHT = (int) $_REQUEST['h'];
   list($EXT,$MIME) = mimetype($MEDIA);
   if($EXT === false){
     $EXT  = 'unknown';
@@ -30,9 +31,9 @@
   }
 
   //media to local file
-  if(preg_match('#^(https?|ftp)://#i',$MEDIA)){
-    //handle external media
-    $FILE = get_from_URL($MEDIA,$EXT,$CACHE);
+  if(preg_match('#^(https?)://#i',$MEDIA)){
+    //handle external images 
+    if(strncmp($MIME,'image/',6) == 0) $FILE = get_from_URL($MEDIA,$EXT,$CACHE);
     if(!$FILE){
       //download failed - redirect to original URL
       header('Location: '.$MEDIA);
@@ -70,7 +71,7 @@
   }
 
   // finally send the file to the client
-  sendFile($FILE,$MIME);
+  sendFile($FILE,$MIME,$CACHE);
 
 /* ------------------------------------------------------------------------ */
 
@@ -78,15 +79,35 @@
  * Set headers and send the file to the client
  *
  * @author Andreas Gohr <andi@splitbrain.org>
+ * @author Ben Coburn <btcoburn@silicodon.net>
  */
-function sendFile($file,$mime){
+function sendFile($file,$mime,$cache){
+  global $conf;
+  $fmtime = filemtime($file);
   // send headers
   header("Content-Type: $mime");
-  http_conditionalRequest(filemtime($file));
-  list($start,$len) = http_rangeRequest(filesize($file));
-  header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
-  header('Pragma: public');
+  // smart http caching headers
+  if ($cache==-1) {
+    // cache
+    // cachetime or one hour
+    header('Expires: '.gmdate("D, d M Y H:i:s", time()+max($conf['cachetime'], 3600)).' GMT');
+    header('Cache-Control: public, proxy-revalidate, no-transform, max-age='.max($conf['cachetime'], 3600));
+    header('Pragma: public');
+  } else if ($cache>0) {
+    // recache
+    // remaining cachetime + 10 seconds so the newly recached media is used
+    header('Expires: '.gmdate("D, d M Y H:i:s", $fmtime+$conf['cachetime']+10).' GMT');
+    header('Cache-Control: public, proxy-revalidate, no-transform, max-age='.max($fmtime-time()+$conf['cachetime']+10, 0));
+    header('Pragma: public');
+  } else if ($cache==0) {
+    // nocache
+    header('Cache-Control: must-revalidate, no-transform, post-check=0, pre-check=0');
+    header('Pragma: public');
+  }
   header('Accept-Ranges: bytes');
+  //send important headers first, script stops here if '304 Not Modified' response
+  http_conditionalRequest($fmtime);
+  list($start,$len) = http_rangeRequest(filesize($file));
 
   //application mime type is downloadable
   if(substr($mime,0,11) == 'application'){
@@ -151,42 +172,6 @@ function http_rangeRequest($size){
   return array($start,$tot);
 }
 
-/**
- * Checks and sets HTTP headers for conditional HTTP requests
- *
- * @author Simon Willison <swillison@gmail.com>
- * @link   http://simon.incutio.com/archive/2003/04/23/conditionalGet
- */
-function http_conditionalRequest($timestamp){
-    // A PHP implementation of conditional get, see 
-    //   http://fishbowl.pastiche.org/archives/001132.html
-    $last_modified = substr(date('r', $timestamp), 0, -5).'GMT';
-    $etag = '"'.md5($last_modified).'"';
-    // Send the headers
-    header("Last-Modified: $last_modified");
-    header("ETag: $etag");
-    // See if the client has provided the required headers
-    $if_modified_since = isset($_SERVER['HTTP_IF_MODIFIED_SINCE']) ?
-        stripslashes($_SERVER['HTTP_IF_MODIFIED_SINCE']) :
-        false;
-    $if_none_match = isset($_SERVER['HTTP_IF_NONE_MATCH']) ?
-        stripslashes($_SERVER['HTTP_IF_NONE_MATCH']) : 
-        false;
-    if (!$if_modified_since && !$if_none_match) {
-        return;
-    }
-    // At least one of the headers is there - check them
-    if ($if_none_match && $if_none_match != $etag) {
-        return; // etag is there but doesn't match
-    }
-    if ($if_modified_since && $if_modified_since != $last_modified) {
-        return; // if-modified-since is there but doesn't match
-    }
-    // Nothing has changed since their last request - serve a 304 and exit
-    header('HTTP/1.0 304 Not Modified');
-    exit;
-}
-
 /**
  * Resizes the given image to the given size
  *
@@ -198,6 +183,8 @@ function get_resized($file, $ext, $w, $h=0){
   $info  = getimagesize($file);
   if(!$h) $h = round(($w * $info[1]) / $info[0]);
 
+  // we wont scale up to infinity
+  if($w > 2000 || $h > 2000) return $file;
 
   //cache
   $local = getCacheName($file,'.media.'.$w.'x'.$h.'.'.$ext);
@@ -239,16 +226,18 @@ function calc_cache($cache){
 function get_from_URL($url,$ext,$cache){
   global $conf;
 
+  // if no cache or fetchsize just redirect
+  if ($cache==0)           return false;
+  if (!$conf['fetchsize']) return false;
+
   $local = getCacheName(strtolower($url),".media.$ext");
   $mtime = @filemtime($local); // 0 if not exists
 
   //decide if download needed:
-  if( $cache == 0 ||                             // never cache
-      ($mtime != 0 && $cache != -1) ||           // exists but no endless cache
-      ($mtime == 0) ||                           // not exists
-      ($cache != -1 && $mtime < time()-$cache)   // expired
+  if( ($mtime == 0) ||                           // cache does not exist
+      ($cache != -1 && $mtime < time()-$cache)   // 'recache' and cache has expired
     ){
-      if(io_download($url,$local)){
+      if(image_download($url,$local)){
         return $local;
       }else{
         return false;
@@ -262,6 +251,38 @@ function get_from_URL($url,$ext,$cache){
   return false;
 }
 
+/**
+ * Download image files
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function image_download($url,$file){
+  global $conf;
+  $http = new DokuHTTPClient();
+  $http->max_bodysize = $conf['fetchsize'];
+  $http->timeout = 25; //max. 25 sec
+  $http->header_regexp = '!\r\nContent-Type: image/(jpe?g|gif|png)!i';
+
+  $data = $http->get($url);
+  if(!$data) return false;
+
+  $fileexists = @file_exists($file);
+  $fp = @fopen($file,"w");
+  if(!$fp) return false;
+  fwrite($fp,$data);
+  fclose($fp);
+  if(!$fileexists and $conf['fperm']) chmod($file, $conf['fperm']);
+
+  // check if it is really an image
+  $info = @getimagesize($file);
+  if(!$info){
+    @unlink($file);
+    return false;
+  }
+
+  return true;
+}
+
 /**
  * resize images using external ImageMagick convert program
  *
@@ -277,11 +298,13 @@ function resize_imageIM($ext,$from,$from_w,$from_h,$to,$to_w,$to_h){
   // prepare command
   $cmd  = $conf['im_convert'];
   $cmd .= ' -resize '.$to_w.'x'.$to_h.'!';
+  if ($ext == 'jpg' || $ext == 'jpeg') {
+      $cmd .= ' -quality '.$conf['jpg_quality'];
+  }
   $cmd .= " $from $to";
 
   @exec($cmd,$out,$retval);
   if ($retval == 0) return true;
-
   return false;
 }
 
@@ -343,7 +366,7 @@ function resize_imageGD($ext,$from,$from_w,$from_h,$to,$to_w,$to_h){
     if(!function_exists('imagejpeg')){
       $okay = false;
     }else{
-      $okay = imagejpeg($newimg, $to, 70);
+      $okay = imagejpeg($newimg, $to, $conf['jpg_quality']);
     }
   }elseif($ext == 'png') {
     if(!function_exists('imagepng')){
