@@ -6,7 +6,7 @@
  * @author     chinsan <chinsan@mail2000.com.tw>
  */
 
-$lang['admin_acl']  = '設定權限控制清單(ACL)';
+$lang['admin_acl']  = '設定 ACL 存取名單';
 $lang['acl_group']  = '群組';
 $lang['acl_user']   = '帳號';
 $lang['acl_perms']  = '設定權限於';
@@ -19,4 +19,5 @@ $lang['acl_perm4']  = '新增頁面';
 $lang['acl_perm8']  = '上傳圖檔';
 $lang['acl_perm16'] = '刪除檔案';
 $lang['acl_new']    = '新增管理規則';
+
 //Setup VIM: ex: et ts=2 enc=utf-8 :
