@@ -9,7 +9,7 @@
 if(!defined('DOKU_INC')) die();
 
 if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
-require_once(DOKU_PLUGIN.'base.php');
+require_once(DOKU_INC.'inc/plugin.php');
 
 /**
  * All DokuWiki plugins to extend the admin function
@@ -21,4 +21,4 @@ class DokuWiki_Action_Plugin extends DokuWiki_Plugin {
     trigger_error('register() not implemented in '.get_class($this), E_USER_WARNING);
   }
 
-}
\ No newline at end of file
+}
