@@ -79,7 +79,8 @@ $lang['allowdebug']  = 'Déboguer <b>désactivez si vous n\'en n\'avez pas besoi
 $lang['usewordblock']= 'Bloquer le spam selon les mots utilisés';
 $lang['indexdelay']  = 'Délai avant l\'indexation (sec)';
 $lang['relnofollow'] = 'Utiliser rel="nofollow" sur les liens extérieurs';
-$lang['mailguard']   = 'Cacher les adresses de courriel';
+$lang['mailguard']   = 'Brouiller les adresses de courriel';
+$lang['iexssprotect']= 'Vérifier la présence de code JavaScript ou HTML malveillant dans les fichiers envoyés';
 
 /* Authentication Options */
 $lang['useacl']      = 'Utiliser les listes de contrôle d\'accès';
@@ -88,17 +89,20 @@ $lang['authtype']    = 'Backend d\'authentification';
 $lang['passcrypt']   = 'Méthode de cryptage des mots de passe';
 $lang['defaultgroup']= 'Groupe par défaut';
 $lang['superuser']   = 'Super-utilisateur';
+$lang['manager']     = 'Manager - un groupe ou un utilisateur ayant accès à certaines fonctions de gestion';
 $lang['profileconfirm'] = 'Confirmer par mot de passe les modifications de profil';
 $lang['disableactions'] = 'Désactiver les actions dans DokuWiki';
 $lang['disableactions_check'] = 'Vérifier';
 $lang['disableactions_subscription'] = 'Abonnement/Désabonnement';
 $lang['disableactions_wikicode'] = 'Afficher source/Export natif';
 $lang['disableactions_other'] = 'Autres actions (séparées par des virgules)';
+$lang['sneaky_index'] = 'Par défaut, DokuWiki affichera toutes les catégories dans la vue par index. Activer cette option permet de cacher celles pour lesquelles l\'utilisateur n\'a pas la permission de lecture. Il peut en résulter le masquage de sous-catégories accessibles. Ceci peut rendre l\'index inutilisable avec certaines ACL.';
+$lang['auth_security_timeout'] = 'Délai d\'expiration de sécurité (secondes)';
 
 /* Advanced Options */
 $lang['updatecheck'] = 'Vérifier les mises à jour ? DokuWiki doit pouvoir contacter splitbrain.org.';
 $lang['userewrite']  = 'URLs esthétiques';
-$lang['useslash']    = 'Utiliser / comme séparateur de catégorie dans les URLs';
+$lang['useslash']    = 'Utiliser slash comme séparateur de catégorie dans les URLs';
 $lang['usedraft']    = 'Enregistrer automatiquement un brouillon pendant l\'édition';
 $lang['sepchar']     = 'Séparateur de nom de page';
 $lang['canonical']   = 'Utiliser des URLs canoniques';
@@ -120,11 +124,14 @@ $lang['compress']    = 'Compresser CSS & javascript';
 $lang['hidepages']   = 'Cacher pages correspondant à (expression régulière)';
 $lang['send404']     = 'Renvoyer "HTTP 404/Page Not Found" pour les pages introuvables';
 $lang['sitemap']     = 'Générer carte google du site (jours)';
+$lang['broken_iua']  = 'La fonction ignore_user_abort est-elle opérationnelle sur votre système ? Ceci peut empêcher le fonctionnement de l\'index de recherche. IIS+PHP/
+CGI dysfonctionne. Voir le <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">bug 852</a> pour plus d\'info.';
 
 $lang['rss_type']    = 'Type de flux RSS';
 $lang['rss_linkto']  = 'Lien du flux RSS vers';
 $lang['rss_update']  = 'Fréquence de mise à jour du flux RSS (sec)';
 $lang['recent_days'] = 'Signaler les pages modifiées depuis (jours)';
+$lang['rss_show_summary'] = 'Le flux XML affiche le résumé dans le titre';
 
 /* Target options */
 $lang['target____wiki']      = 'Target pour liens internes';
