@@ -133,8 +133,12 @@ if (!class_exists('configuration')) {
 
       if ($this->_format == 'php') {
 
-        $contents = @php_strip_whitespace($file);
-        $pattern = '/\$'.$this->_name.'\[[\'"]([^=]+)[\'"]\] ?= ?(.*?);(?=[^;]*(?:\$'.$this->_name.'|@include|$))/';
+        if(@file_exists($file)){
+            $contents = @php_strip_whitespace($file);
+        }else{
+            $contents = '';
+        }
+        $pattern = '/\$'.$this->_name.'\[[\'"]([^=]+)[\'"]\] ?= ?(.*?);(?=[^;]*(?:\$'.$this->_name.'|@include|$))/s';
         $matches=array();
         preg_match_all($pattern,$contents,$matches,PREG_SET_ORDER);
 
@@ -145,7 +149,7 @@ if (!class_exists('configuration')) {
           $key = preg_replace('/.\]\[./',CM_KEYMARKER,$matches[$i][1]);
 
           // remove quotes from quoted strings & unescape escaped data
-          $value = preg_replace('/^(\'|")(.*)(?<!\\\\)\1$/','$2',$matches[$i][2]);
+          $value = preg_replace('/^(\'|")(.*)(?<!\\\\)\1$/s','$2',$matches[$i][2]);
           $value = strtr($value, array('\\\\'=>'\\','\\\''=>'\'','\\"'=>'"'));
 
           $config[$key] = $value;
@@ -372,8 +376,8 @@ if (!class_exists('setting')) {
         $key = htmlspecialchars($this->_key);
         $value = htmlspecialchars($value);
 
-        $label = '<label for="config__'.$key.'">'.$this->prompt($plugin).'</label>';
-        $input = '<textarea rows="3" cols="40" id="config__'.$key.'" name="config['.$key.']" class="edit" '.$disable.'>'.$value.'</textarea>';
+        $label = '<label for="config___'.$key.'">'.$this->prompt($plugin).'</label>';
+        $input = '<textarea rows="3" cols="40" id="config___'.$key.'" name="config['.$key.']" class="edit" '.$disable.'>'.$value.'</textarea>';
         return array($label,$input);
     }
 
@@ -432,8 +436,8 @@ if (!class_exists('setting_string')) {
         $key = htmlspecialchars($this->_key);
         $value = htmlspecialchars($value);
 
-        $label = '<label for="config__'.$key.'">'.$this->prompt($plugin).'</label>';
-        $input = '<input id="config__'.$key.'" name="config['.$key.']" type="text" class="edit" value="'.$value.'" '.$disable.'/>';
+        $label = '<label for="config___'.$key.'">'.$this->prompt($plugin).'</label>';
+        $input = '<input id="config___'.$key.'" name="config['.$key.']" type="text" class="edit" value="'.$value.'" '.$disable.'/>';
         return array($label,$input);
     }
   }
@@ -463,8 +467,8 @@ if (!class_exists('setting_password')) {
 
         $key = htmlspecialchars($this->_key);
 
-        $label = '<label for="config__'.$key.'">'.$this->prompt($plugin).'</label>';
-        $input = '<input id="config__'.$key.'" name="config['.$key.']" type="password" class="edit" value="" '.$disable.'/>';
+        $label = '<label for="config___'.$key.'">'.$this->prompt($plugin).'</label>';
+        $input = '<input id="config___'.$key.'" name="config['.$key.']" type="password" class="edit" value="" '.$disable.'/>';
         return array($label,$input);
     }
   }
@@ -500,6 +504,13 @@ if (!class_exists('setting_numeric')) {
   }
 }
 
+if (!class_exists('setting_numericopt')) {
+    class setting_numericopt extends setting_numeric {
+        // just allow an empty config
+        var $_pattern = '/^(|[-]?[0-9]+(?:[-+*][0-9]+)*)$/';
+    }
+}
+
 if (!class_exists('setting_onoff')) {
   class setting_onoff extends setting_numeric {
 
@@ -517,8 +528,8 @@ if (!class_exists('setting_onoff')) {
         $key = htmlspecialchars($this->_key);
         $checked = ($value) ? ' checked="checked"' : '';
 
-        $label = '<label for="config__'.$key.'">'.$this->prompt($plugin).'</label>';
-        $input = '<div class="input"><input id="config__'.$key.'" name="config['.$key.']" type="checkbox" class="checkbox" value="1"'.$checked.$disable.'/></div>';
+        $label = '<label for="config___'.$key.'">'.$this->prompt($plugin).'</label>';
+        $input = '<div class="input"><input id="config___'.$key.'" name="config['.$key.']" type="checkbox" class="checkbox" value="1"'.$checked.$disable.'/></div>';
         return array($label,$input);
     }
 
@@ -563,10 +574,10 @@ if (!class_exists('setting_multichoice')) {
 
         $key = htmlspecialchars($this->_key);
 
-        $label = '<label for="config__'.$key.'">'.$this->prompt($plugin).'</label>';
+        $label = '<label for="config___'.$key.'">'.$this->prompt($plugin).'</label>';
 
         $input = "<div class=\"input\">\n";
-        $input .= '<select class="edit" id="config__'.$key.'" name="config['.$key.']"'.$disable.'>'."\n";
+        $input .= '<select class="edit" id="config___'.$key.'" name="config['.$key.']"'.$disable.'>'."\n";
         foreach ($this->_choices as $choice) {
             $selected = ($value == $choice) ? ' selected="selected"' : '';
             $option = $plugin->getLang($this->_key.'_o_'.$choice);
@@ -724,8 +735,8 @@ if (!class_exists('setting_multicheckbox')) {
                           $plugin->getLang($this->_key.'_'.$choice) : htmlspecialchars($choice));
 
           $input .= '<div class="selection'.$class.'">'."\n";
-          $input .= '<label for="config__'.$key.'_'.$choice.'">'.$prompt."</label>\n";
-          $input .= '<input id="config__'.$key.'_'.$choice.'" name="config['.$key.'][]" type="checkbox" class="checkbox" value="'.$choice.'" '.$disable.' '.$checked."/>\n";
+          $input .= '<label for="config___'.$key.'_'.$choice.'">'.$prompt."</label>\n";
+          $input .= '<input id="config___'.$key.'_'.$choice.'" name="config['.$key.'][]" type="checkbox" class="checkbox" value="'.$choice.'" '.$disable.' '.$checked."/>\n";
           $input .= "</div>\n";
 
           // remove this action from the disabledactions array
@@ -740,11 +751,11 @@ if (!class_exists('setting_multicheckbox')) {
                         " selectiondefault" : "";
 
         $input .= '<div class="other'.$class.'">'."\n";
-        $input .= '<label for="config__'.$key.'_other">'.$plugin->getLang($key.'_other')."</label>\n";
-        $input .= '<input id="config__'.$key.'_other" name="config['.$key.'][other]" type="text" class="edit" value="'.htmlspecialchars($other).'" '.$disable." />\n";
+        $input .= '<label for="config___'.$key.'_other">'.$plugin->getLang($key.'_other')."</label>\n";
+        $input .= '<input id="config___'.$key.'_other" name="config['.$key.'][other]" type="text" class="edit" value="'.htmlspecialchars($other).'" '.$disable." />\n";
         $input .= "</div>\n";
 
-//        $label = '<label for="config__'.$key.'">'.$this->prompt($plugin).'</label>';
+//        $label = '<label for="config___'.$key.'">'.$this->prompt($plugin).'</label>';
         $label = $this->prompt($plugin);
         return array($label,$input);
     }
