@@ -14,7 +14,7 @@ $lang['nosupport']   = '(brugerstyring er ikke understøttet)';
 $lang['badauth']     = 'ugyldig valideringsmekanisme';     // should never be displayed!
 
 $lang['user_id']     = 'Bruger';
-$lang['user_pass']   = 'Password';
+$lang['user_pass']   = 'Adgangskode';
 $lang['user_name']   = 'Navn';
 $lang['user_mail']   = 'E-mail';
 $lang['user_groups'] = 'Grupper';
@@ -45,3 +45,11 @@ $lang['prev']   = 'forrige';
 $lang['next']   = 'næste';
 $lang['last']   = 'sidste';
 
+$lang['edit_usermissing'] = 'Den valgte bruger blev ikke fundet, brugernavnet kan være slettet eller ændret andetsteds.';
+$lang['user_notify'] = 'Meddel bruger';
+$lang['note_notify'] = 'Meddelelses emails er kun sendt hvis brugeren er givet et nyt kodeord.';
+$lang['note_group'] = 'Nye brugere vil blive tilføjet til standard gruppen (%s) hvis ingen gruppe er opgivet.';
+$lang['add_ok'] = 'Bruger succesfuldt tilføjet';
+$lang['add_fail'] = 'Bruger tilføjelse mislykkedes';
+$lang['notify_ok'] = 'Meddelelses email sendt';
+$lang['notify_fail'] = 'Meddelelses email kunne ikke sendes';
