@@ -9,12 +9,12 @@
 $lang['menu'] = 'Управление пользователями'; 
  
 // custom language strings for the plugin
-$lang['noauth']      = '(аутентификация пользователей недоступна)';
+$lang['noauth']      = '(авторизация пользователей недоступна)';
 $lang['nosupport']   = '(управление пользователями не поддерживается)';
 
 $lang['badauth']     = 'некорректный механизм аутентификации';     // should never be displayed!
 
-$lang['user_id']     = 'Имя пользователя';
+$lang['user_id']     = 'Логин';
 $lang['user_pass']   = 'Пароль';
 $lang['user_name']   = 'Полное имя';
 $lang['user_mail']   = 'Е-мэйл';
@@ -46,3 +46,13 @@ $lang['prev']   = 'назад';
 $lang['next']   = 'вперед';
 $lang['last']   = 'в конец';
 
+// added after 2006-03-09 release
+$lang['edit_usermissing'] = 'Выбранный пользователь не найден. Возможно, указанный логин был удален или изменен извне.';
+$lang['user_notify'] = 'Сообщить пользователю';
+$lang['note_notify'] = 'Е-мэйлы с уведомлением посылаются только в случае получения нового пароля.';
+$lang['note_group'] = 'Если группа не указана, новые пользователи будут добавлены в группу по умолчанию (%s).';
+$lang['add_ok'] = 'Пользователь успешно добавлен';
+$lang['add_fail'] = 'Не удалось добавить пользователя';
+$lang['notify_ok'] = 'Е-мэйл с уведомлением был послан';
+$lang['notify_fail'] = 'Не удалось послать е-мэйл с уведомлением';
+
